.. bgg-cohomology documentation master file, created by
   sphinx-quickstart on Sun Jul 26 15:43:10 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

bgg-cohomology
==============

This is the documentation of the `bgg-cohomology` sage package. You can find the 
package `here on github <https://github.com/RikVoorhaar/bgg-cohomology>`_.

This package serves as an implementation of the algorithm described in the following 
preprint:
`A computer algorithm for the BGG resolution <https://arxiv.org/abs/1911.00871>`_

Installation and Usage
======================

.. toctree::

   installation
   tutorial
   maps_nb
   cokernels
   quantum_center_nb

API Reference
=============

.. toctree::
   
   bggcomplex
   la_modules
   quantum_center
   weight_set

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
